@@ -186,3 +186,55 @@ ssize_t write(int fd, const void *buf, size_t nbytes)
 }
 #endif
 
+/* Pth hard wrapper for syscall readv(2) */
+#if cpp
+#if defined(SYS_readv)
+#define PTH_SC_readv(a1,a2,a3) ((ssize_t)syscall(SYS_readv,(a1),(a2),(a3)))
+#else
+#define PTH_SC_readv readv
+#endif
+#endif /* cpp */
+#if PTH_SYSCALL_HARD && defined(SYS_readv)
+ssize_t readv(int fd, const struct iovec *iov, int iovcnt)
+{
+    pth_implicit_init();
+    return pth_readv(fd, iov, iovcnt);
+}
+#endif
+
+/* Pth hard wrapper for syscall writev(2) */
+#if cpp
+#if defined(SYS_writev)
+#define PTH_SC_writev(a1,a2,a3) ((ssize_t)syscall(SYS_writev,(a1),(a2),(a3)))
+#else
+#define PTH_SC_writev writev
+#endif
+#endif /* cpp */
+#if PTH_SYSCALL_HARD && defined(SYS_writev)
+ssize_t writev(int fd, const struct iovec *iov, int iovcnt)
+{
+    pth_implicit_init();
+    return pth_writev(fd, iov, iovcnt);
+}
+#endif
+
+/* Pth hard wrapper for pread(3) [internally fully emulated] */
+#if PTH_SYSCALL_HARD
+ssize_t pread(int, void *, size_t, off_t);
+ssize_t pread(int fd, void *buf, size_t nbytes, off_t offset)
+{
+    pth_implicit_init();
+    return pth_pread(fd, buf, nbytes, offset);
+}
+#endif
+
+/* Pth hard wrapper for pwrite(3) [internally fully emulated] */
+#if PTH_SYSCALL_HARD
+ssize_t pwrite(int, const void *, size_t, off_t);
+ssize_t pwrite(int fd, const void *buf, size_t nbytes, off_t offset)
+{
+    pth_implicit_init();
+    return pth_pwrite(fd, buf, nbytes, offset);
+}
+#endif
+
