@@ -30,13 +30,15 @@
 
 #include "pth.h"
 
+#include "test_common.h"
+
 /* our simple query structure */
 struct query {
     pth_message_t head; /* the standard message header */
     char *string;       /* the query ingredients */
 };
 
-/* out worker thread which translates the string to upper case */
+/* our worker thread which translates the string to upper case */
 static void *worker(void *_dummy)
 {
     pth_msgport_t mp;
